<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtre :</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Sélectionner la police du terminal</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Police :</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Bookmarks</source>
        <translation>Signets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Appuyer sur &quot;%1&quot; pour voir le terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Onglet suivant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Onglet précédent</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Left</source>
        <translation>Déplacer l&apos;onglet à &amp;gauche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>Move Tab &amp;Right</source>
        <translation>Déplacer l&apos;onglet à &amp;droite</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Séparer le terminal &amp;horizontalement</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Séparer le terminal &amp;verticalement</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Concaténer le sous-terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Effacer le terminal actif</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>Keep window open when it loses focus</source>
        <translation>Garder la fenêtre ouverte lorsqu&apos;elle perd le focus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Previous Tab in History</source>
        <translation>Onglet &amp;précédent dans l&apos;historique</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>&amp;Next Tab in History</source>
        <translation>Onglet &amp;suivant dans l&apos;historique</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Tab</source>
        <translation>Onglet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Go to</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Top Subterminal</source>
        <translation>Sous-terminal &amp;au-dessus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Sous-terminal &amp;en-dessous</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Sous-terminal à &amp;gauche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Sous-terminal à &amp;droite</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Copier la sélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste Clip&amp;board</source>
        <translation>Coller le &amp;presse-papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Paste S&amp;election</source>
        <translation>Coller la &amp;sélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;in</source>
        <translation>Zoomer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom &amp;out</source>
        <translation>Dézoomer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Zoom rese&amp;t</source>
        <translation>R&amp;éinitialiser le zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>&amp;Find...</source>
        <translation>&amp;Chercher...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Handle history...</source>
        <translation>Gérer l&apos;historique ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Enregistrer la session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Charger une session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Permuter le menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Rename session</source>
        <translation>Renommer la session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nouvel onglet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nouvel onglet depuis la &amp;présélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 Terminaux &amp;horizontaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 Terminaux &amp;verticaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Terminau&amp;x</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fermer l&apos;onglet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Préférences...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Masquer les bordures de la fenêtre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Afficher la barre des onglets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Toggle Bookmarks</source>
        <translation>Permuter les marque-pages</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Bas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Top</source>
        <translation>&amp;Haut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Right</source>
        <translation>&amp;Droite</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>&amp;Left</source>
        <translation>&amp;Gauche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Disposition des onglets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;None</source>
        <translation>&amp;Aucun</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Disposition de la barre de &amp;défilement</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;BlockCursor</source>
        <translation>Curseur &amp;Bloc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Curseur So&amp;uligné</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;IBeamCursor</source>
        <translation>Curseur en forme de &amp;I</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>Forme du curseur du &amp;clavier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Exit QTerminal</source>
        <translation>Quitter QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Do not ask again</source>
        <translation>Ne plus demander</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Are you sure you want to exit?</source>
        <translation>Êtes-vous sûr de vouloir quitter ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Un émulateur de terminal multiplateforme léger et puissant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>LXQt Project</source>
        <translation>LXQt Project</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Development: </source>
        <translation>Développement&#xa0;: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Configuration du terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Menu déroulant</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Signets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Schéma des couleurs</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Style des widgets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Position de la barre de défilement</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Position des onglets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Afficher la barre des menus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Masquer la barre d&apos;onglets avec un seul onglet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Afficher une bordure autour du terminal courant</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Transparence de l&apos;application</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Transparence du terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Démarrer avec les préréglages :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Aucun (terminal unique)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminaux horizontaux</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminaux verticaux</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminaux</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Police</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Changer...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Forme du curseur</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Changer le titre de la fenêtre en fonction du terminal actuel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Changer l&apos;icône de la fenêtre en fonction du terminal actuel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Activer la prise en charge du texte bidirectionnel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Image de fond :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Afficher la taille du terminal lors du redimensionnement</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Largeur de l&apos;onglet fixe :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Afficher le bouton de fermeture sur chaque onglet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Marges du terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Utiliser la tables des caractères contenue dans la police</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Les accélérateurs sont activés par Alt et peuvent parasiter l&apos;usage du terminal.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Pas d&apos;accélérateur de menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>Émulation</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Action après le collage</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>Confirmer le collage sur plusieurs lignes</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Couper les retours à la ligne dans le texte collé</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>Ouvrir un nouveau terminal dans le répertoire courant</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>Enregistrer la taille lors de la fermeture</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>Enregistrer la position lors de la fermeture</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>Demander confirmation lors de la fermeture</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Historique illimité</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Taille de l&apos;historique (en lignes)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>$TERM par défaut</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>Démarrer avec cette taille :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Mode d&apos;arrière-plan :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Étirer</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Zoomer</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Ajuster</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Centrer</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Spécifiez si les caractères de dessin de boîte doivent être dessinés par QTerminal en interne ou laissés aux bibliothèques de rendu de polices sous-jacentes.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Active ou désactive l&apos;utilisation de police de caractère gras pour le rendu de couleurs intenses</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Utiliser des caractères gras pour des couleurs intenses</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Masquer les bordures de la fenêtre</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Quel comportement émuler. Notez que cela ne doit pas nécessairement correspondre à votre système d&apos;exploitation&lt;/p&gt;&lt;p&gt;Si vous n&apos;êtes pas sûr, utiliser le &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Cette commande sera exécutée avec un argument contenant le nom de fichier d&apos;un fichier temporaire contenant l&apos;historique de défilement</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>Gérer l&apos;historique des commandes</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>Obtenir la taille actuelle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Ouvrir un nouvel onglet à droite de l&apos;onglet actif</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Si non cochée, le nouvel onglet sera ouvert comme l&apos;onglet le plus à droite</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>Fermer l&apos;onglet d&apos;un clique du milieu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Forcer la désactivation du mode de collage entre crochets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation>Caractères de sélection du mot</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Lorsque vous sélectionnez un texte par mot, considérez ces caractères comme faisant partie des mots en plus des caractères alphanumériques</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Le mode Collage entre crochets est utile pour coller des chaînes multilignes.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>Cloche sonore</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Pour modifier un raccourci :
1. Double-cliquez sur sa touche
2. Appuyez sur la combinaison souhaitée et relâchez-la
3. Cliquez sur un raccourci ou appuyez sur Entrée

Pour supprimer / désactiver un raccourci, au point 2, appuyez uniquement sur un modificateur (comme Maj)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>Touche</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>Afficher au démarrage</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Un bouton de verrouillage est affiché sur la barre d&apos;onglets horizontale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>Garder la fenêtre ouverte lorsqu&apos;elle perd le focus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>Hauteur</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>Raccourci :</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>Edit bookmark file contents</source>
        <translation>Éditer le fichier des signets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1005"/>
        <source>Enable bookmarks</source>
        <translation>Activer les signets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1014"/>
        <source>Bookmark file</source>
        <translation>Fichier des signets</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1027"/>
        <source>Find...</source>
        <translation>Chercher...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1036"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Vous pouvez spécifier votre propre emplacement de fichier de signets. Il permet un partage facile des signets avec des outils tels que OwnCloud ou Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Pas de barre de défilement</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Curseur bloc</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Curseur soulignement</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Curseur en I</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Sans déplacement</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Défiler vers le haut</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Défiler vers le bas</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="206"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Défaut système</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="271"/>
        <source>Examples</source>
        <translation>Exemples</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Choose a background image</source>
        <translation>Choisir une image de fond d&apos;écran</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="422"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Images (*.bmp *.jpg *.png *.svg *.xpm )</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="512"/>
        <source>Open bookmarks file</source>
        <translation>Ouvrir le fichier de signets</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>XML files (*.xml)</source>
        <translation>Fichiers XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="515"/>
        <source>All files (*)</source>
        <translation>Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Voulez-vous écraser ce fichier de signets&#xa0;?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Le nom du fichier de signets ne se termine pas par &apos;.xml&apos;.
Êtes-vous sûr de vouloir l&apos;écraser&#xa0;?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Impossible d&apos;écrire des signets dans ce fichier&#xa0;:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Signets synchronisés</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>Shell No. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>Nom de l&apos;onglet</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>Nouveau nom d&apos;onglet :</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>Sélection de la couleur du titre du nouvel onglet</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>Fermer la session</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>Changer la couleur du titre</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Charger une session</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Liste des sessions sauvegardées :</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Fenêtre principale</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Actions</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Éditer</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;À propos...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>À propos de &amp;Qt...</translation>
    </message>
</context>
</TS>
